@@ -1,7 +1,11 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.19 2006/08/12 17:36:43 bkorb Exp $
+ *  $Id: autogen.h,v 4.27 2006/12/10 19:41:26 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-12-10 11:11:17 bkorb"
+ *  Last Committed:    $Date: 2006/12/10 19:41:26 $
+ *
  *  Global header file for AutoGen
  */
 
@@ -125,7 +129,7 @@ typedef struct template_lib_marker tTlibMark;
  *
  *  Procedure for loading a template function
  */
-typedef tMacro* (tLoadProc)( tTemplate*, tMacro*, const char** ppzScan );
+typedef tMacro* (tLoadProc)( tTemplate*, tMacro*, char const** ppzScan );
 typedef tLoadProc* tpLoadProc;
 
 typedef void (tUnloadProc)( tMacro* );
@@ -152,11 +156,11 @@ typedef tHdlrProc* tpHdlrProc;
 
 struct template_lib_marker {
     union {
-        char        str[4];  /* {'A', 'G', 'L', 'B'} */
-        long        i[1];
+        unsigned char   str[4];  /* {'A', 'G', 'L', 'B'} */
+        unsigned int    i[1];
     }           magic;
-    short       revision;    /* TEMPLATE_REVISION    */
-    short       funcSum;     /* FUNCTION_CKSUM       */
+    unsigned short      revision;    /* TEMPLATE_REVISION    */
+    unsigned short      funcSum;     /* FUNCTION_CKSUM       */
 };
 
 /*
@@ -251,7 +255,7 @@ struct scanContext {
 
 struct outSpec {
     tOutSpec*   pNext;
-    const char* pzFileFmt;
+    char const* pzFileFmt;
     char        zSuffix[ 1 ];
 };
 
@@ -374,9 +378,9 @@ MODE int         templLineNo      VALUE( 1 );
 MODE tScanCtx*   pBaseCtx         VALUE( NULL );
 MODE tScanCtx*   pCurCtx          VALUE( NULL );
 MODE tScanCtx*   pDoneCtx         VALUE( NULL );
-MODE u_int       endMacLen        VALUE( 0  );
+MODE size_t      endMacLen        VALUE( 0  );
 MODE char        zEndMac[   8 ]   VALUE( "" );
-MODE u_int       startMacLen      VALUE( 0  );
+MODE size_t      startMacLen      VALUE( 0  );
 MODE char        zStartMac[  8 ]  VALUE( "" );
 MODE int         guileFailure     VALUE( 0 );
 
@@ -399,7 +403,7 @@ MODE tDefEntry*  pCurrentEntry    VALUE( NULL );
  *  GLOBAL STRINGS
  */
 #define MKSTRING( name, val ) \
-        MODE const char z ## name[ sizeof( val )] VALUE( val )
+        MODE char const z ## name[ sizeof( val )] VALUE( val )
 
 MKSTRING( AllocWhat,  "Could not allocate a %d byte %s\n" );
 MKSTRING( AllocErr,   "Allocation Failure" );
@@ -411,26 +415,14 @@ MKSTRING( NotStr,     "ERROR: %s is not a string\n" );
 MKSTRING( DevNull,    "/dev/null" );
 MKSTRING( ShellEnv,   "SHELL" );
 MKSTRING( Format,     "format" );
-
-/*
- *  It may seem odd that there are two 'nil' strings.  It is used by
- *  evalExpression() to distinguish between an actual value of a zero-
- *  length string, and a defaulted value because there was no value
- *  available.  (In fact, that routine will always select 'zDefaultNil'
- *  except when "runShell()" returns NULL.  A NULL result means an empty
- *  string that is valid (zNil) as opposed to an empty string due to
- *  an unknown value (zDefaultNil).  This distinction is utilized in
- *  the Select_Match_Existence() and Select_Match_NonExistence() functions.
- */
 MKSTRING( Nil,        "" );
-MKSTRING( DefaultNil, "" );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  *  GLOBAL PROCEDURES
  */
 #ifndef HAVE_STRLCPY
-extern size_t strlcpy( char* dest, const char* src, size_t n );
+extern size_t strlcpy( char* dest, char const* src, size_t n );
 #endif
 #ifdef ENABLE_FMEMOPEN
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
@@ -438,7 +430,7 @@ extern size_t strlcpy( char* dest, const char* src, size_t n );
  *  IF we have fopencookie or funopen, then we also have our own fmemopen
  */
 
-extern FILE * ag_fmemopen (void *buf, ssize_t len, const char *mode);
+extern FILE * ag_fmemopen (void *buf, ssize_t len, char const *mode);
 #endif
 #include "proto.h"
 
@@ -476,110 +468,83 @@ extern char* ag_scribble( size_t size );
 /*
  *  Code variations based on the version of Guile:
  */
-#if GUILE_VERSION < 106000
+#if GUILE_VERSION < 107000  /* pre-Guile 1.7.x */
 
-# define AG_SCM_STRLEN(_s)       SCM_LENGTH(_s)
-# define AG_SCM_STRING_P(_s)     gh_string_p(_s)
-# define AG_SCM_NUMBER_P(_s)     gh_number_p(_s)
-# define AG_SCM_BOOL_P(_b)       gh_boolean_p(_b)
-# define AG_SCM_SYM_P(_s)        gh_symbol_p(_s)
-# define AG_SCM_IS_PROC(_p)      gh_procedure_p(_p)
-# define AG_SCM_CHAR_P(_c)       gh_char_p(_c)
-# define AG_SCM_VEC_P(_v)        gh_vector_p(_v)
-# define AG_SCM_PAIR_P(_p)       gh_pair_p(_p)
-# define AG_SCM_NUM_P(_n)        gh_number_p(_n)
-# define AG_SCM_LIST_P(_l)       gh_list_p(_l)
+#if GUILE_VERSION < 106000 /* Guile 1.4 */
 
-# define AG_SCM_MKSTR(_s, _ch)   MUST NOT USE
+#   define AG_SCM_STRING_P(_s)          gh_string_p(_s)
+#   define AG_SCM_BOOL_P(_b)            gh_boolean_p(_b)
+#   define AG_SCM_SYM_P(_s)             gh_symbol_p(_s)
+#   define AG_SCM_IS_PROC(_p)           gh_procedure_p(_p)
+#   define AG_SCM_CHAR_P(_c)            gh_char_p(_c)
+#   define AG_SCM_VEC_P(_v)             gh_vector_p(_v)
+#   define AG_SCM_PAIR_P(_p)            gh_pair_p(_p)
+#   define AG_SCM_NUM_P(_n)             gh_number_p(_n)
+#   define AG_SCM_LIST_P(_l)            gh_list_p(_l)
+#   define AG_SCM_STR2SCM(_st,_sz)      gh_str2scm(_st,_sz)
+#   define AG_SCM_STR02SCM(_s)          gh_str02scm(_s)
 
-# define AG_SCM_EVAL_STR(_s)     gh_eval_str(_s)
-# define AG_SCM_CHARS(_s)        SCM_CHARS(_s)
-# define AG_SCM_STR2SCM(_st,_sz) gh_str2scm(_st,_sz)
-# define AG_SCM_STR02SCM(_s)     gh_str02scm(_s)
-# define AG_SCM_INT2SCM(_i)      gh_int2scm(_i)
-# define AG_SCM_SCM2INT(_i)      gh_scm2int(_i)
-# define AG_SCM_LONG2SCM(_i)     gh_long2scm(_i)
-# define AG_SCM_SCM2LONG(_i)     gh_scm2long(_i)
+#else /* Guile 1.6.x */
 
-static inline char* ag_scm2zchars( SCM s, tCC* type )
-{
+#   define AG_SCM_STRING_P(_s)          SCM_STRINGP(_s)
+#   define AG_SCM_BOOL_P(_b)            SCM_BOOLP(_b)
+#   define AG_SCM_SYM_P(_s)             SCM_SYMBOLP(_s)
+#   define AG_SCM_IS_PROC(_p)           SCM_NFALSEP( scm_procedure_p(_p))
+#   define AG_SCM_CHAR_P(_c)            SCM_CHARP(_c)
+#   define AG_SCM_VEC_P(_v)             SCM_VECTORP(_v)
+#   define AG_SCM_PAIR_P(_p)            SCM_NFALSEP( scm_pair_p(_p))
+#   define AG_SCM_NUM_P(_n)             SCM_NUMBERP(_n)
+#   define AG_SCM_LIST_P(_l)            SCM_NFALSEP( scm_list_p(_l))
+#   define AG_SCM_STR2SCM(_st,_sz)      scm_mem2string(_st,_sz)
+#   define AG_SCM_STR02SCM(_s)          scm_makfrom0str(_s)
+#endif
+
+  static inline char* ag_scm2zchars( SCM s, tCC* type )
+  {
     if (! AG_SCM_STRING_P( s ))
         AG_ABEND( aprf( zNotStr, type ));
 
     if (SCM_SUBSTRP(s))
         s = scm_makfromstr( SCM_CHARS(s), SCM_LENGTH(s), 0 );
-    return SCM_CHARS(s);  /* pre-Guile 1.7.x */
-}
+    return SCM_CHARS(s);
+  }
 
-#elif GUILE_VERSION < 107000
+# define AG_SCM_STRLEN(_s)              SCM_LENGTH(_s)
+# define AG_SCM_CHARS(_s)               SCM_CHARS(_s)
 
-# define AG_SCM_STRLEN(_s)       SCM_LENGTH(_s)
-# define AG_SCM_STRING_P(_s)     SCM_STRINGP(_s)
-# define AG_SCM_NUMBER_P(_s)     SCM_NUMBERP(_s)
-# define AG_SCM_BOOL_P(_b)       SCM_BOOLP(_b)
-# define AG_SCM_SYM_P(_s)        SCM_SYMBOLP(_s)
-# define AG_SCM_IS_PROC(_p)      SCM_NFALSEP( scm_procedure_p(_p))
-# define AG_SCM_CHAR_P(_c)       SCM_CHARP(_c)
-# define AG_SCM_VEC_P(_v)        SCM_VECTORP(_v)
-# define AG_SCM_PAIR_P(_p)       SCM_NFALSEP( scm_pair_p(_p))
-# define AG_SCM_NUM_P(_n)        SCM_NUMBERP(_n)
-# define AG_SCM_LIST_P(_l)       SCM_NFALSEP( scm_list_p(_l))
+#else /* Guile 1.7 and following */
 
-# define AG_SCM_MKSTR(_s, _ch)   MUST NOT USE
-
-# define AG_SCM_EVAL_STR(_s)     scm_c_eval_string(_s)
-# define AG_SCM_CHARS(_s)        SCM_CHARS(_s)
-# define AG_SCM_STR2SCM(_st,_sz) scm_mem2string(_st,_sz)
-# define AG_SCM_STR02SCM(_s)     scm_makfrom0str(_s)
-# define AG_SCM_INT2SCM(_i)      gh_int2scm(_i)
-# define AG_SCM_SCM2INT(_i)      gh_scm2int(_i)
-# define AG_SCM_LONG2SCM(_i)     gh_long2scm(_i)
-# define AG_SCM_SCM2LONG(_i)     gh_scm2long(_i)
-
-static inline char* ag_scm2zchars( SCM s, tCC* type )
-{
-    if (! AG_SCM_STRING_P( s ))
-        AG_ABEND( aprf( zNotStr, type ));
-
-    if (SCM_SUBSTRP(s))
-        s = scm_makfromstr( SCM_CHARS(s), SCM_LENGTH(s), 0 );
-    return SCM_CHARS(s);  /* pre-Guile 1.7.x */
-}
-
-
-#else
   extern char* ag_scm2zchars( SCM s, tCC* type );
 
 # if GUILE_VERSION < 108000
-#   define AG_SCM_STRLEN(_s)     SCM_STRING_LENGTH(_s)
-#   define AG_SCM_CHARS(_s)      SCM_STRING_CHARS(_s)
-#   define AG_SCM_VEC_P(_v)      SCM_VECTORP(_v)
+#   define AG_SCM_STRLEN(_s)            SCM_STRING_LENGTH(_s)
+#   define AG_SCM_CHARS(_s)             SCM_STRING_CHARS(_s)
+#   define AG_SCM_VEC_P(_v)             SCM_VECTORP(_v)
 # else
-#   define AG_SCM_STRLEN(_s)     scm_c_string_length(_s)
-#   define AG_SCM_CHARS(_s)      SCM_STRING_CHARS(_s)
-#   define AG_SCM_VEC_P(_v)      scm_is_vector(_v)
+#   define AG_SCM_STRLEN(_s)            scm_c_string_length(_s)
+#   define AG_SCM_CHARS(_s)             scm_i_string_chars(_s)
+#   define AG_SCM_VEC_P(_v)             scm_is_vector(_v)
 # endif
 
-# define AG_SCM_STRING_P(_s)     scm_is_string(_s)
-# define AG_SCM_NUMBER_P(_s)     scm_is_number(_s)
-# define AG_SCM_BOOL_P(_b)       SCM_BOOLP(_b)
-# define AG_SCM_SYM_P(_s)        SCM_SYMBOLP(_s)
-# define AG_SCM_IS_PROC(_p)      scm_is_true( scm_procedure_p(_p))
-# define AG_SCM_CHAR_P(_c)       SCM_CHARP(_c)
-# define AG_SCM_PAIR_P(_p)       scm_is_true( scm_pair_p(_p))
-# define AG_SCM_NUM_P(_n)        SCM_NUMBERP(_n)
-# define AG_SCM_LIST_P(_l)       SCM_NFALSEP( scm_list_p(_l))
+# define AG_SCM_STRING_P(_s)            scm_is_string(_s)
+# define AG_SCM_BOOL_P(_b)              SCM_BOOLP(_b)
+# define AG_SCM_SYM_P(_s)               SCM_SYMBOLP(_s)
+# define AG_SCM_IS_PROC(_p)             scm_is_true( scm_procedure_p(_p))
+# define AG_SCM_CHAR_P(_c)              SCM_CHARP(_c)
+# define AG_SCM_PAIR_P(_p)              scm_is_true( scm_pair_p(_p))
+# define AG_SCM_NUM_P(_n)               scm_is_number(_n)
+# define AG_SCM_LIST_P(_l)              SCM_NFALSEP( scm_list_p(_l))
+# define AG_SCM_STR2SCM(_st,_sz)        scm_from_locale_stringn(_st,_sz)
+# define AG_SCM_STR02SCM(_s)            scm_from_locale_string(_s)
+#endif /* pre-1.7 / 1.7 and following */
 
-# define AG_SCM_MKSTR(_s, _ch)   MUST NOT USE
-
-# define AG_SCM_EVAL_STR(_s)     scm_c_eval_string(_s)
-# define AG_SCM_STR2SCM(_st,_sz) scm_from_locale_stringn(_st,_sz)
-# define AG_SCM_STR02SCM(_s)     scm_from_locale_string(_s)
-# define AG_SCM_INT2SCM(_i)      gh_int2scm(_i)
-# define AG_SCM_SCM2INT(_i)      gh_scm2int(_i)
-# define AG_SCM_LONG2SCM(_i)     gh_long2scm(_i)
-# define AG_SCM_SCM2LONG(_i)     gh_scm2long(_i)
-#endif
+/*
+ *  Guile version invariant!!
+ */
+#define AG_SCM_INT2SCM(_i)              gh_int2scm(_i)
+#define AG_SCM_SCM2INT(_i)              gh_scm2int(_i)
+#define AG_SCM_LONG2SCM(_i)             gh_long2scm(_i)
+#define AG_SCM_SCM2LONG(_i)             gh_scm2long(_i)
 
 static inline SCM ag_eval( tCC* pzStr )
 {
@@ -599,7 +564,6 @@ static inline SCM ag_eval( tCC* pzStr )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/autogen.h */
