@@ -1,12 +1,16 @@
 
 /*
- *  $Id: expGuile.c,v 4.4 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: expGuile.c,v 4.14 2006/09/24 02:58:59 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-09-23 19:53:20 bkorb"
+ *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *
  *  This module implements the expression functions that should
  *  be part of Guile.
  */
 
 /*
- *  AutoGen copyright 1992-2005 Bruce Korb
+ *  AutoGen copyright 1992-2006 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -28,66 +32,82 @@
 LOCAL teGuileType
 gh_type_e( SCM typ )
 {
-    if (gh_boolean_p( typ ))
-        return GH_TYPE_BOOLEAN;
-
-    if (gh_symbol_p( typ ))
-        return GH_TYPE_SYMBOL;
-
-    if (gh_char_p( typ ))
-        return GH_TYPE_CHAR;
-
-    if (gh_vector_p( typ ))
-        return GH_TYPE_VECTOR;
-
-    if (gh_pair_p( typ ))
-        return GH_TYPE_PAIR;
-
-    if (gh_number_p( typ ))
-        return GH_TYPE_NUMBER;
-
-    if (gh_string_p( typ ))
-        return GH_TYPE_STRING;
-
-    if (gh_procedure_p( typ ))
-        return GH_TYPE_PROCEDURE;
-
-    if (gh_list_p( typ ))
-        return GH_TYPE_LIST;
-
-    if (gh_inexact_p( typ ))
-        return GH_TYPE_INEXACT;
-
-    if (gh_exact_p( typ ))
-        return GH_TYPE_EXACT;
+    if (AG_SCM_BOOL_P(   typ ))   return GH_TYPE_BOOLEAN;
+    if (AG_SCM_SYM_P(    typ ))   return GH_TYPE_SYMBOL;
+    if (AG_SCM_STRING_P( typ ))   return GH_TYPE_STRING;
+    if (AG_SCM_IS_PROC(  typ ))   return GH_TYPE_PROCEDURE;
+    if (AG_SCM_CHAR_P(   typ ))   return GH_TYPE_CHAR;
+    if (AG_SCM_VEC_P(    typ ))   return GH_TYPE_VECTOR;
+    if (AG_SCM_PAIR_P(   typ ))   return GH_TYPE_PAIR;
+    if (AG_SCM_NUM_P(    typ ))   return GH_TYPE_NUMBER;
+    if (AG_SCM_LIST_P(   typ ))   return GH_TYPE_LIST;
 
     return GH_TYPE_UNDEFINED;
 }
 
+
 LOCAL SCM
 ag_scm_c_eval_string_from_file_line( tCC* pzExpr, tCC* pzFile, int line )
 {
     SCM port;
 
+    if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
+        fprintf( pfTrace, "eval from file %s line %d:\n%s\n", pzFile, line,
+                 pzExpr );
+    }
+
+#if GUILE_VERSION < 106000
     {
         tSCC zEx[] = "eval-string-from-file-line";
         SCM  expr  = scm_makfrom0str( pzExpr );
         port = scm_mkstrport( SCM_INUM0, expr, SCM_OPN | SCM_RDNG, zEx );
     }
+#else
+    port = scm_open_input_string( AG_SCM_STR02SCM( pzExpr ));
+#endif
 
+#if GUILE_VERSION < 107000
     {
-        static SCM file = SCM_UNDEFINED;
+        static SCM   file = SCM_UNDEFINED;
+        static char* pzFl = NULL;
+
         scm_t_port* pt;
 
-        if (  (file == SCM_UNDEFINED)
-           || (strcmp( SCM_CHARS( file ), pzFile ) != 0) )
-            file = scm_makfrom0str( pzFile );
+        if (  (pzFl == NULL)
+           || (strcmp( AG_SCM_CHARS( file ), pzFile ) != 0) )  {
+            if (pzFl != NULL)
+                AGFREE(pzFl);
+            AGDUPSTR(pzFl, pzFile, "eval file name");
+            file = AG_SCM_STR02SCM( pzFile );
+        }
 
         pt = SCM_PTAB_ENTRY(port);
         pt->line_number = line - 1;
         pt->file_name   = file;
     }
 
+#else
+    {
+        static SCM file = SCM_UNDEFINED;
+        static char* pzOldFile = NULL;
+
+        if ((pzOldFile == NULL) || (strcmp( pzOldFile, pzFile ) != 0)) {
+            if (pzOldFile != NULL)
+                AGFREE( pzOldFile );
+
+            AGDUPSTR( pzOldFile, pzFile, "scheme file source" );
+            file = scm_from_locale_string( pzFile );
+        }
+
+        scm_set_port_filename_x( port, file );
+    }
+
+    {
+        SCM ln = scm_from_int( line );
+        scm_set_port_line_x( port, ln );
+    }
+#endif
+
     {
         SCM ans = SCM_UNSPECIFIED;
 
@@ -237,10 +257,10 @@ SCM
 ag_scm_sum( SCM list )
 {
     int  len = scm_ilength( list );
-    unsigned long sum = 0;
+    long sum = 0;
 
     if (len <= 0)
-        return gh_int2scm( 0 );
+        return AG_SCM_INT2SCM( 0 );
 
     do  {
         SCM  car = SCM_CAR( list );
@@ -286,11 +306,11 @@ ag_scm_string_to_c_name_x( SCM str )
     int   len;
     char* pz;
 
-    if (! gh_string_p( str ))
+    if (! AG_SCM_STRING_P( str ))
         scm_wrong_type_arg( zFun, 1, str );
 
-    len = SCM_LENGTH( str );
-    pz  = SCM_CHARS( str );
+    len = AG_SCM_STRLEN( str );
+    pz  = (char*)(void*)AG_SCM_CHARS( str );
     while (--len >= 0) {
         char ch = *pz;
         if (! isalnum( ch )) {
@@ -326,13 +346,13 @@ ag_scm_string_upcase_x( SCM str )
     int   len;
     char* pz;
 
-    if (! gh_string_p( str ))
+    if (! AG_SCM_STRING_P( str ))
         return SCM_UNDEFINED;
 
-    len = SCM_LENGTH( str );
-    pz  = SCM_CHARS( str );
+    len = AG_SCM_STRLEN( str );
+    pz  = (char*)(void*)AG_SCM_CHARS( str );
     while (--len >= 0) {
-         char ch = *pz;                                                         
+         char ch = *pz;
         if (islower( ch ))
             *pz = toupper( ch );
         pz++;
@@ -356,11 +376,11 @@ SCM
 ag_scm_string_upcase( SCM str )
 {
     SCM res;
-    if (! gh_string_p( str ))
+    if (! AG_SCM_STRING_P( str ))
         return SCM_UNDEFINED;
 
-    res = gh_str2scm( SCM_CHARS( str ), SCM_LENGTH( str ));
-    ag_scm_string_upcase_x( res );
+    res = AG_SCM_STR2SCM( AG_SCM_CHARS( str ), AG_SCM_STRLEN( str ));
+    scm_string_upcase_x( res );
     return res;
 }
 
@@ -381,11 +401,11 @@ ag_scm_string_capitalize_x( SCM str )
     char*   pz;
     ag_bool word_start = AG_TRUE;
 
-    if (! gh_string_p( str ))
+    if (! AG_SCM_STRING_P( str ))
         return SCM_UNDEFINED;
 
-    len = SCM_LENGTH( str );
-    pz  = SCM_CHARS( str );
+    len = AG_SCM_STRLEN( str );
+    pz  = (char*)(void*)AG_SCM_CHARS( str );
 
     while (--len >= 0) {
         char ch = *pz;
@@ -423,10 +443,10 @@ SCM
 ag_scm_string_capitalize( SCM str )
 {
     SCM res;
-    if (! gh_string_p( str ))
+    if (! AG_SCM_STRING_P( str ))
         return SCM_UNDEFINED;
 
-    res = gh_str2scm( SCM_CHARS( str ), SCM_LENGTH( str ));
+    res = AG_SCM_STR2SCM( AG_SCM_CHARS( str ), AG_SCM_STRLEN( str ));
     ag_scm_string_capitalize_x( res );
     return res;
 }
@@ -447,11 +467,11 @@ ag_scm_string_downcase_x( SCM str )
     int   len;
     char* pz;
 
-    if (! gh_string_p( str ))
+    if (! AG_SCM_STRING_P( str ))
         return SCM_UNDEFINED;
 
-    len = SCM_LENGTH( str );
-    pz  = SCM_CHARS( str );
+    len = AG_SCM_STRLEN( str );
+    pz  = (char*)(void*)AG_SCM_CHARS( str );
     while (--len >= 0) {
         char ch = *pz;
         if (isupper( ch ))
@@ -477,10 +497,10 @@ SCM
 ag_scm_string_downcase( SCM str )
 {
     SCM res;
-    if (! gh_string_p( str ))
+    if (! AG_SCM_STRING_P( str ))
         return SCM_UNDEFINED;
 
-    res = gh_str2scm( SCM_CHARS( str ), SCM_LENGTH( str ));
+    res = AG_SCM_STR2SCM( AG_SCM_CHARS( str ), AG_SCM_STRLEN( str ));
     ag_scm_string_downcase_x( res );
     return res;
 }
@@ -488,7 +508,6 @@ ag_scm_string_downcase( SCM str )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/expGuile.c */
