@@ -1,6 +1,9 @@
 
 /*
- *  $Id: tpLoad.c,v 4.11 2006/06/24 23:36:07 bkorb Exp $
+ *  $Id: tpLoad.c,v 4.15 2006/12/10 16:43:00 bkorb Exp $
+ *
+ * Time-stamp:        "2006-12-02 10:33:18 bkorb"
+ * Last Committed:    $Date: 2006/12/10 16:43:00 $
  *
  *  This module will load a template and return a template structure.
  */
@@ -50,7 +53,7 @@ findTemplate( tCC* pzTemplName )
     while (pT != NULL) {
         if (streqvcmp( pzTemplName, pT->pzTplName ) == 0)
             break;
-        pT = (tTemplate*)(pT->pNext);
+        pT = (tTemplate*)(void*)(pT->pNext);
     }
     return pT;
 }
@@ -86,7 +89,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
      *  We will not mess with embedded ones.
      */
     if (*pzFName == '$') {
-        if (! optionMakePath( pzFullName, MAXPATHLEN, pzFName,
+        if (! optionMakePath( pzFullName, (int)AG_PATH_MAX, pzFName,
                               autogenOptions.pzProgPath ))
             return FAILURE;
 
@@ -104,7 +107,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
      *  Check for an immediately accessible file
      */
     if (canReadFile( pzFName )) {
-        strlcpy( pzFullName, pzFName, MAXPATHLEN );
+        strlcpy( pzFullName, pzFName, AG_PATH_MAX );
         goto findFileReturn;
     }
 
@@ -126,7 +129,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
         tCC** papSL = papSuffixList;
 
         char* pzEnd = pzFullName +
-            snprintf( pzFullName, MAXPATHLEN-MAX_SUFFIX_LEN, "%s.", pzFName );
+            snprintf( pzFullName, AG_PATH_MAX-MAX_SUFFIX_LEN, "%s.", pzFName );
 
         do  {
             strcpy( pzEnd, *(papSL++) ); /* must fit */
@@ -158,7 +161,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
              *  IF one of our template paths starts with '$', then expand it.
              */
             if (*pzDir == '$') {
-                if (! optionMakePath( pzFullName, MAXPATHLEN, pzDir,
+                if (! optionMakePath( pzFullName, (int)AG_PATH_MAX, pzDir,
                                       autogenOptions.pzProgPath ))
                     pzDir = ".";
                 else
@@ -168,7 +171,7 @@ findFile( tCC* pzFName, char* pzFullName, tCC** papSuffixList )
             }
 
             pzEnd  = pzFullName
-                + snprintf( pzFullName, MAXPATHLEN-MAX_SUFFIX_LEN,
+                + snprintf( pzFullName, AG_PATH_MAX-MAX_SUFFIX_LEN,
                             zDirFmt, pzDir, pzFName );
 
             if (canReadFile( pzFullName ))
@@ -316,7 +319,7 @@ loadTemplate( tCC* pzFileName )
 
     {
         tSCC*       apzSfx[] = { "tpl", "agl", NULL };
-        static char zRealFile[ MAXPATHLEN ];
+        static char zRealFile[ AG_PATH_MAX ];
 
         /*
          *  Find the template file somewhere
@@ -417,7 +420,7 @@ cleanup( tTemplate* pTF )
         tTemplate* pT = pNamedTplList;
         if (pT == NULL)
             break;
-        pNamedTplList = (tTemplate*)pT->pNext;
+        pNamedTplList = (tTemplate*)(void*)(pT->pNext);
         unloadTemplate( pT );
     }
 
@@ -434,7 +437,6 @@ cleanup( tTemplate* pTF )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/tpLoad.c */
