@@ -1,14 +1,14 @@
 
 /*
- *  $Id: cook.c,v 4.2 2005/06/07 22:26:44 bkorb Exp $
- *  Time-stamp:      "2005-05-20 13:58:56 bkorb"
+ *  $Id: cook.c,v 4.7 2006/09/28 01:26:33 bkorb Exp $
+ *  Time-stamp:      "2006-09-24 15:21:02 bkorb"
  *
  *  This file contains the routines that deal with processing quoted strings
  *  into an internal format.
  */
 
 /*
- *  Automated Options copyright 1992-2005 Bruce Korb
+ *  Automated Options copyright 1992-2006 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -58,9 +58,9 @@
  * private:
  *
  * what:  escape-process a string fragment
- * arg:   + const char* + pzScan  + points to character after the escape +
+ * arg:   + char const* + pzScan  + points to character after the escape +
  * arg:   + char*       + pRes    + Where to put the result byte +
- * arg:   + char        + nl_ch   + replacement char if scanned char is \n +
+ * arg:   + u_int       + nl_ch   + replacement char if scanned char is \n +
  *
  * ret-type: unsigned int
  * ret-desc: The number of bytes consumed processing the escaped character.
@@ -81,7 +81,7 @@
  * err:  @code{NULL} is returned if the string(s) is/are mal-formed.
 =*/
 unsigned int
-ao_string_cook_escape_char( const char* pzIn, char* pRes, char nl )
+ao_string_cook_escape_char( char const* pzIn, char* pRes, u_int nl )
 {
     unsigned int  res = 1;
 
@@ -94,7 +94,7 @@ ao_string_cook_escape_char( const char* pzIn, char* pRes, char nl )
         res++;
         /* FALLTHROUGH */
     case '\n':        /* NL  - emit newline        */
-        *pRes = nl;
+        *pRes = (char)nl;
         return res;
 
     case 'a': *pRes = '\a'; break;
@@ -106,7 +106,7 @@ ao_string_cook_escape_char( const char* pzIn, char* pRes, char nl )
     case 'v': *pRes = '\v'; break;
 
     case 'x':         /* HEX Escape       */
-        if (isxdigit( *pzIn ))  {
+        if (isxdigit( (int)*pzIn ))  {
             unsigned int  val;
             unsigned char ch = *pzIn++;
 
@@ -140,7 +140,7 @@ ao_string_cook_escape_char( const char* pzIn, char* pRes, char nl )
          *  IF the character copied was an octal digit,
          *  THEN set the output character to an octal value
          */
-        if (isdigit( *pRes ) && (*pRes < '8'))  {
+        if (isdigit( (int)*pRes ) && (*pRes < '8'))  {
             unsigned int  val = *pRes - '0';
             unsigned char ch  = *pzIn++;
 
@@ -239,7 +239,7 @@ ao_string_cook( char* pzScan, int* pLineCt )
             pzS++;
 
         scan_for_quote:
-            while (isspace(*pzS))
+            while (isspace((int)*pzS))
                 if (*(pzS++) == '\n')
                     (*pLineCt)++;
 
@@ -325,7 +325,7 @@ ao_string_cook( char* pzScan, int* pLineCt )
              *  THEN we do the full escape character processing
              */
             else if (q != '\'') {
-                int ct = ao_string_cook_escape_char( pzS, pzD-1, '\n' );
+                int ct = ao_string_cook_escape_char( pzS, pzD-1, (u_int)'\n' );
                 if (ct == 0)
                     return NULL;
 
@@ -349,7 +349,6 @@ ao_string_cook( char* pzScan, int* pLineCt )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/cook.c */
