@@ -1,13 +1,13 @@
 
 /*
- *  $Id: guileopt.c,v 4.7 2005/06/07 22:26:44 bkorb Exp $
- * Time-stamp:      "2005-04-17 11:10:52 bkorb"
+ *  $Id: guileopt.c,v 4.10 2006/10/06 05:29:00 bkorb Exp $
+ * Time-stamp:      "2006-10-05 21:04:56 bkorb"
  *
  *  This module will export the option values to the Guile environment.
  */
 
 /*
- *  Automated Options copyright 1992-2005 Bruce Korb
+ *  Automated Options copyright 1992-2006 Bruce Korb
  *
  *  Automated Options is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -50,10 +50,18 @@
  */
 #include "config.h"
 #include <stdio.h>
+#if defined(HAVE_STRING_H)
+#  include <string.h>
+#elif defined(HAVE_STRINGS_H)
+#  include <strings.h>
+#else
+   choke me -- no strings header
+#endif
 #include <guile/gh.h>
 
 #include "autoopts/options.h"
-#include "autoopts.h"
+
+#define SKIP_OPT(p)  (((p)->fOptState & (OPTST_DOCUMENT|OPTST_OMITTED)) != 0)
 
 /*=export_func  export_options_to_guile
  * what:  put the option state into Guile symbols
@@ -65,32 +73,30 @@
  *        interpreter.
 =*/
 void
-export_options_to_guile( pOpts )
-    tOptions* pOpts;
+export_options_to_guile( tOptions* pOpts )
 {
     tOptDesc*  pOD = pOpts->pOptDesc;
     int        ct  = pOpts->presetOptCt;
     char z[ 4096 ];
 
     for (;--ct >= 0;pOD++) {
+        static char const opt_state[] =
+            "(define opt-enabled-%s #%c) "
+            "(define have-opt-%s #%c)";
+        static char const num_arg[]  = "(define opt-arg-%s %ld)\n";
+        static char const str_arg[]  = "(define opt-arg-%s \"%s\")\n";
+        static char const bool_arg[] = "(define opt-arg-%s #%c)\n";
+
+
         if (SKIP_OPT(pOD))
             continue;
 
         /*
          *  We always indicate the presence/absence enabled/disabled state.
          */
-        sprintf( z, "(define opt-enabled-%s #%c)\n", pOD->pz_Name,
-                 (DISABLED_OPT(pOD) ? 'f' : 't'));
-#ifdef DEBUG
-        fputs( z, stderr );
-#endif
-        gh_eval_str( z );
-
-        sprintf( z, "(define have-opt-%s #%c)\n", pOD->pz_Name,
-                 UNUSED_OPT( pOD ) ? 'f' : 't' );
-#ifdef DEBUG
-        fputs( z, stderr );
-#endif
+        sprintf( z, opt_state,
+                 pOD->pz_Name, DISABLED_OPT(pOD) ? 'f' : 't',
+                 pOD->pz_Name, UNUSED_OPT( pOD ) ? 'f' : 't' );
         gh_eval_str( z );
 
         /*
@@ -99,20 +105,33 @@ export_options_to_guile( pOpts )
          *  take numeric arguments will always have a value set.)
          */
         if (UNUSED_OPT( pOD )) {
-            if (OPTST_GET_ARGTYPE(pOD->fOptState) == OPARG_TYPE_NUMERIC) {
-                sprintf( z, "(define opt-arg-%s %d)\n", pOD->pz_Name,
-                         (uintptr_t)pOD->pzLastArg );
-#ifdef DEBUG
-                fputs( z, stderr );
-#endif
+            switch (OPTST_GET_ARGTYPE(pOD->fOptState)) {
+            case OPARG_TYPE_NONE:
+            case OPARG_TYPE_ENUMERATION:
+            case OPARG_TYPE_HIERARCHY:
+                /* forget it. */
+                break;
+
+            case OPARG_TYPE_STRING:
+                if (pOD->optArg.argString != 0) {
+                    sprintf(z, str_arg, pOD->pz_Name, pOD->optArg.argString);
+                    gh_eval_str( z );
+                }
+                break;
+
+            case OPARG_TYPE_BOOLEAN:
+                sprintf(z, bool_arg, pOD->pz_Name,
+                        pOD->optArg.argBool ? 't' : 'f');
                 gh_eval_str( z );
-            }
-            else if (pOD->pzLastArg != 0) {
-                sprintf( z, "(define opt-arg-%s \"%s\")\n", pOD->pz_Name,
-                         pOD->pzLastArg );
-#ifdef DEBUG
-                fputs( z, stderr );
-#endif
+                break;
+
+            case OPARG_TYPE_MEMBERSHIP:
+                if (pOD->optArg.argEnum == 0)
+                    break;
+                /* FALLTHROUGH */
+
+            case OPARG_TYPE_NUMERIC:
+                sprintf( z, num_arg, pOD->pz_Name, pOD->optArg.argInt );
                 gh_eval_str( z );
             }
             continue;
@@ -122,18 +141,15 @@ export_options_to_guile( pOpts )
          *  IF the option can occur several times, then emit the count.
          */
         if (pOD->optMaxCt > 1) {
-            sprintf( z, "(define opt-ct-%s %ld)\n",
+            sprintf( z, "(define opt-ct-%s %d)\n",
                      pOD->pz_Name, pOD->optOccCt );
-#ifdef DEBUG
-            fputs( z, stderr );
-#endif
             gh_eval_str( z );
         }
 
         /*
          *  IF there is a stack of option args, emit them as a list.
          */
-        if (pOD->optCookie != NULL) {
+        if ((pOD->optCookie != NULL) && (pOD->fOptState & OPTST_STACKED)) {
             tArgList* pAL = (tArgList*)pOD->optCookie;
             int       act = pAL->useCt;
             tCC**     ppa = pAL->apzArgs;
@@ -143,9 +159,6 @@ export_options_to_guile( pOpts )
             while (--act >= 0)
                 pz += sprintf( pz, " \"%s\"", *(ppa++) );
             strcpy( pz, " ))\n" );
-#ifdef DEBUG
-            fputs( z, stderr );
-#endif
             gh_eval_str( z );
 
         }
@@ -154,23 +167,15 @@ export_options_to_guile( pOpts )
          *  IF the option takes a numeric value, set the value
          */
         else if (OPTST_GET_ARGTYPE(pOD->fOptState) == OPARG_TYPE_NUMERIC) {
-            sprintf( z, "(define opt-arg-%s %d)\n", pOD->pz_Name,
-                     (uintptr_t)pOD->pzLastArg );
-#ifdef DEBUG
-            fputs( z, stderr );
-#endif
+            sprintf( z, num_arg, pOD->pz_Name, pOD->optArg.argInt );
             gh_eval_str( z );
         }
 
         /*
          *  IF the option has a string value, emit that.
          */
-        else if (pOD->pzLastArg != 0) {
-            sprintf( z, "(define opt-arg-%s \"%s\")\n", pOD->pz_Name,
-                     pOD->pzLastArg );
-#ifdef DEBUG
-            fputs( z, stderr );
-#endif
+        else if (pOD->optArg.argString != 0) {
+            sprintf( z, str_arg, pOD->pz_Name, pOD->optArg.argString );
             gh_eval_str( z );
         }
     }
@@ -180,7 +185,6 @@ export_options_to_guile( pOpts )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/guileopt.c */
