@@ -1,7 +1,7 @@
 
 /*
- *  $Id: nested.c,v 4.4 2006/03/31 19:52:10 bkorb Exp $
- *  Time-stamp:      "2005-07-27 10:10:28 bkorb"
+ *  $Id: nested.c,v 4.9 2006/11/27 01:52:23 bkorb Exp $
+ *  Time-stamp:      "2006-09-24 15:27:32 bkorb"
  *
  *   Automated Options Nested Values module.
  */
@@ -53,30 +53,30 @@
 static void
 removeBackslashes( char* pzSrc );
 
-static const char*
-scanQuotedString( const char* pzTxt );
+static char const*
+scanQuotedString( char const* pzTxt );
 
 static tOptionValue*
-addStringValue( void** pp, const char* pzName, size_t nameLen,
-                const char* pzValue, size_t dataLen );
+addStringValue( void** pp, char const* pzName, size_t nameLen,
+                char const* pzValue, size_t dataLen );
 
 static tOptionValue*
-addBoolValue( void** pp, const char* pzName, size_t nameLen,
-                const char* pzValue, size_t dataLen );
+addBoolValue( void** pp, char const* pzName, size_t nameLen,
+                char const* pzValue, size_t dataLen );
 
 static tOptionValue*
-addNumberValue( void** pp, const char* pzName, size_t nameLen,
-                const char* pzValue, size_t dataLen );
+addNumberValue( void** pp, char const* pzName, size_t nameLen,
+                char const* pzValue, size_t dataLen );
 
 static tOptionValue*
-addNestedValue( void** pp, const char* pzName, size_t nameLen,
+addNestedValue( void** pp, char const* pzName, size_t nameLen,
                 char* pzValue, size_t dataLen, tOptionLoadMode mode );
 
-static const char*
-scanNameEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode );
+static char const*
+scanNameEntry( char const* pzName, tOptionValue* pRes, tOptionLoadMode mode );
 
-static const char*
-scanXmlEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode );
+static char const*
+scanXmlEntry( char const* pzName, tOptionValue* pRes, tOptionLoadMode mode );
 
 static void
 unloadNestedArglist( tArgList* pAL );
@@ -115,8 +115,8 @@ removeBackslashes( char* pzSrc )
  *
  *  Find the end of a quoted string, skipping escaped quote characters.
  */
-static const char*
-scanQuotedString( const char* pzTxt )
+static char const*
+scanQuotedString( char const* pzTxt )
 {
     char q = *(pzTxt++); /* remember the type of quote */
 
@@ -154,8 +154,8 @@ scanQuotedString( const char* pzTxt )
  *  Associate a name with either a string or no value.
  */
 static tOptionValue*
-addStringValue( void** pp, const char* pzName, size_t nameLen,
-                const char* pzValue, size_t dataLen )
+addStringValue( void** pp, char const* pzName, size_t nameLen,
+                char const* pzValue, size_t dataLen )
 {
     tOptionValue* pNV;
     size_t sz = nameLen + dataLen + sizeof(*pNV);
@@ -188,8 +188,8 @@ addStringValue( void** pp, const char* pzName, size_t nameLen,
  *  Associate a name with either a string or no value.
  */
 static tOptionValue*
-addBoolValue( void** pp, const char* pzName, size_t nameLen,
-                const char* pzValue, size_t dataLen )
+addBoolValue( void** pp, char const* pzName, size_t nameLen,
+                char const* pzValue, size_t dataLen )
 {
     tOptionValue* pNV;
     size_t sz = nameLen + sizeof(*pNV) + 1;
@@ -197,12 +197,12 @@ addBoolValue( void** pp, const char* pzName, size_t nameLen,
     pNV = AGALOC( sz, "option name/bool value pair" );
     if (pNV == NULL)
         return NULL;
-    while (isspace( *pzValue ) && (dataLen > 0)) {
+    while (isspace( (int)*pzValue ) && (dataLen > 0)) {
         dataLen--; pzValue++;
     }
     if (dataLen == 0)
         pNV->v.boolVal = 0;
-    else if (isdigit( *pzValue ))
+    else if (isdigit( (int)*pzValue ))
         pNV->v.boolVal = atoi( pzValue );
     else switch (*pzValue) {
     case 'f':
@@ -228,8 +228,8 @@ addBoolValue( void** pp, const char* pzName, size_t nameLen,
  *  Associate a name with either a string or no value.
  */
 static tOptionValue*
-addNumberValue( void** pp, const char* pzName, size_t nameLen,
-                const char* pzValue, size_t dataLen )
+addNumberValue( void** pp, char const* pzName, size_t nameLen,
+                char const* pzValue, size_t dataLen )
 {
     tOptionValue* pNV;
     size_t sz = nameLen + sizeof(*pNV) + 1;
@@ -237,7 +237,7 @@ addNumberValue( void** pp, const char* pzName, size_t nameLen,
     pNV = AGALOC( sz, "option name/bool value pair" );
     if (pNV == NULL)
         return NULL;
-    while (isspace( *pzValue ) && (dataLen > 0)) {
+    while (isspace( (int)*pzValue ) && (dataLen > 0)) {
         dataLen--; pzValue++;
     }
     if (dataLen == 0)
@@ -259,7 +259,7 @@ addNumberValue( void** pp, const char* pzName, size_t nameLen,
  *  Associate a name with either a string or no value.
  */
 static tOptionValue*
-addNestedValue( void** pp, const char* pzName, size_t nameLen,
+addNestedValue( void** pp, char const* pzName, size_t nameLen,
                 char* pzValue, size_t dataLen, tOptionLoadMode mode )
 {
     tOptionValue* pNV;
@@ -291,21 +291,22 @@ addNestedValue( void** pp, const char* pzName, size_t nameLen,
  *  We have an entry that starts with a name.  Find the end of it, cook it
  *  (if called for) and create the name/value association.
  */
-static const char*
-scanNameEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode )
+static char const*
+scanNameEntry( char const* pzName, tOptionValue* pRes, tOptionLoadMode mode )
 {
     tOptionValue* pNV;
-    const char* pzScan = pzName+1;
-    const char* pzVal;
+    char const* pzScan = pzName+1;
+    char const* pzVal;
     size_t nameLen = 1;
     size_t dataLen = 0;
 
-    while (ISNAMECHAR( *pzScan ))  { pzScan++; nameLen++; }
+    while (ISNAMECHAR( (int)*pzScan ))  { pzScan++; nameLen++; }
 
-    while (isspace( *pzScan )) {
+    while (isspace( (int)*pzScan )) {
         char ch = *(pzScan++);
         if ((ch == '\n') || (ch == ',')) {
-            addStringValue( &(pRes->v.nestVal), pzName, nameLen, NULL, 0 );
+            addStringValue( &(pRes->v.nestVal), pzName, nameLen, NULL,
+                            (size_t)0);
             return pzScan - 1;
         }
     }
@@ -313,12 +314,13 @@ scanNameEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode )
     switch (*pzScan) {
     case '=':
     case ':':
-        while (isspace( *++pzScan ))  ;
+        while (isspace( (int)*++pzScan ))  ;
         switch (*pzScan) {
         case ',':  goto comma_char;
         case '"':
         case '\'': goto quote_char;
-        case NUL:  addStringValue( &(pRes->v.nestVal), pzName, nameLen, NULL, 0);
+        case NUL:  addStringValue( &(pRes->v.nestVal), pzName, nameLen, NULL,
+                                   (size_t)0);
                    goto leave_scan_name;
         default:   goto default_char;
         }
@@ -329,7 +331,7 @@ scanNameEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode )
         /* FALLTHROUGH */
 
     case NUL:
-        addStringValue( &(pRes->v.nestVal), pzName, nameLen, NULL, 0 );
+        addStringValue(&(pRes->v.nestVal), pzName, nameLen, NULL, (size_t)0);
         break;
 
     case '"':
@@ -381,16 +383,16 @@ scanNameEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode )
  *  directive.  If it is something else, then whatever it is we are looking
  *  at is bogus.  Returning NULL stops processing.
  */
-static const char*
-scanXmlEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode )
+static char const*
+scanXmlEntry( char const* pzName, tOptionValue* pRes, tOptionLoadMode mode )
 {
     size_t nameLen = 1, valLen = 0;
-    const char*   pzScan = ++pzName;
-    const char*   pzVal;
+    char const*   pzScan = ++pzName;
+    char const*   pzVal;
     tOptionValue  valu;
     tOptionValue* pNewVal;
 
-    if (! isalpha(*pzName)) {
+    if (! isalpha((int)*pzName)) {
         switch (*pzName) {
         default:
             pzName = NULL;
@@ -411,7 +413,7 @@ scanXmlEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode )
         return pzName;
     }
 
-    while (isalpha( *++pzScan ))  nameLen++;
+    while (isalpha( (int)*++pzScan ))  nameLen++;
     if (nameLen > 64)
         return NULL;
     valu.valType = OPARG_TYPE_STRING;
@@ -432,7 +434,7 @@ scanXmlEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode )
     case '/':
         if (*++pzScan != '>')
             return NULL;
-        addStringValue( &(pRes->v.nestVal), pzName, nameLen, NULL, 0 );
+        addStringValue(&(pRes->v.nestVal), pzName, nameLen, NULL, (size_t)0);
         return pzScan+2;
 
     default:  return NULL;
@@ -445,7 +447,7 @@ scanXmlEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode )
         char z[68];
         char* pzD = z;
         int  ct = nameLen;
-        const char* pzS = pzName;
+        char const* pzS = pzName;
 
         *(pzD++) = '<';
         *(pzD++) = '/';
@@ -461,12 +463,12 @@ scanXmlEntry( const char* pzName, tOptionValue* pRes, tOptionLoadMode mode )
             return NULL;
         valLen = (pzScan - pzVal);
         pzScan += nameLen + 3;
-        while (isspace( *pzScan ))  pzScan++;
+        while (isspace(  (int)*pzScan ))  pzScan++;
     }
 
     switch (valu.valType) {
     case OPARG_TYPE_NONE:
-        addStringValue( &(pRes->v.nestVal), pzName, nameLen, NULL, 0 );
+        addStringValue( &(pRes->v.nestVal), pzName, nameLen, NULL, (size_t)0);
         break;
 
     case OPARG_TYPE_STRING:
@@ -511,10 +513,10 @@ static void
 unloadNestedArglist( tArgList* pAL )
 {
     int ct = pAL->useCt;
-    tOptionValue** ppNV = (tOptionValue**)(pAL->apzArgs);
+    tCC** ppNV = pAL->apzArgs;
 
     while (ct-- > 0) {
-        tOptionValue* pNV = *(ppNV++);
+        tOptionValue* pNV = (tOptionValue*)(void*)*(ppNV++);
         if (pNV->valType == OPARG_TYPE_HIERARCHY)
             unloadNestedArglist( pNV->v.nestVal );
         free( pNV );
@@ -566,8 +568,8 @@ sortNestedList( tArgList* pAL )
      */
     for (ix = 0; ++ix < lm;) {
         int iy = ix-1;
-        tOptionValue* pNewNV = (tOptionValue*)pAL->apzArgs[ix];
-        tOptionValue* pOldNV = (tOptionValue*)pAL->apzArgs[iy];
+        tOptionValue* pNewNV = (tOptionValue*)(void*)(pAL->apzArgs[ix]);
+        tOptionValue* pOldNV = (tOptionValue*)(void*)(pAL->apzArgs[iy]);
 
         /*
          *  For as long as the new entry precedes the "old" entry,
@@ -576,7 +578,7 @@ sortNestedList( tArgList* pAL )
          */
         while (strcmp( pOldNV->pzName, pNewNV->pzName ) > 0) {
             pAL->apzArgs[iy+1] = (void*)pOldNV;
-            pOldNV = (tOptionValue*)pAL->apzArgs[--iy];
+            pOldNV = (tOptionValue*)(void*)(pAL->apzArgs[--iy]);
             if (iy < 0)
                 break;
         }
@@ -594,8 +596,8 @@ sortNestedList( tArgList* pAL )
  * private:
  *
  * what:  parse a hierarchical option argument
- * arg:   + const char*     + pzTxt   + the text to scan +
- * arg:   + const char*     + pzName  + the name for the text +
+ * arg:   + char const*     + pzTxt   + the text to scan +
+ * arg:   + char const*     + pzName  + the name for the text +
  * arg:   + size_t          + nameLen + the length of "name"  +
  * arg:   + tOptionLoadMode + mode    + the value formation mode    +
  *
@@ -608,7 +610,7 @@ sortNestedList( tArgList* pAL )
  *  option that takes a hierarchical value.
 =*/
 tOptionValue*
-optionLoadNested( const char* pzTxt, const char* pzName, size_t nameLen,
+optionLoadNested( char const* pzTxt, char const* pzName, size_t nameLen,
                   tOptionLoadMode mode )
 {
     tOptionValue* pRes;
@@ -621,7 +623,7 @@ optionLoadNested( const char* pzTxt, const char* pzName, size_t nameLen,
         errno = EINVAL;
         return NULL;
     }
-    while (isspace( *pzTxt ))  pzTxt++;
+    while (isspace( (int)*pzTxt ))  pzTxt++;
     if (*pzTxt == NUL) {
         errno = ENOENT;
         return NULL;
@@ -649,8 +651,8 @@ optionLoadNested( const char* pzTxt, const char* pzName, size_t nameLen,
      *  Scan until we hit a NUL.
      */
     do  {
-        while (isspace( *pzTxt ))  pzTxt++;
-        if (isalpha( *pzTxt )) {
+        while (isspace( (int)*pzTxt ))  pzTxt++;
+        if (isalpha( (int)*pzTxt )) {
             pzTxt = scanNameEntry( pzTxt, pRes, mode );
         }
         else switch (*pzTxt) {
@@ -689,8 +691,8 @@ void
 optionNestedVal( tOptions* pOpts, tOptDesc* pOD )
 {
     tOptionValue* pOV =
-        optionLoadNested(pOD->pzLastArg, pOD->pz_Name, strlen( pOD->pz_Name ),
-                         OPTION_LOAD_UNCOOKED);
+        optionLoadNested(pOD->optArg.argString, pOD->pz_Name,
+                         strlen(pOD->pz_Name), OPTION_LOAD_UNCOOKED);
 
     if (pOV != NULL)
         addArgListEntry( &(pOD->optCookie), (void*)pOV );
@@ -699,7 +701,6 @@ optionNestedVal( tOptions* pOpts, tOptDesc* pOD )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of autoopts/nested.c */
