@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for autoopts
- * Generated Sat Aug 12 10:37:43 PDT 2006
+ * Generated Sun Dec 17 12:01:41 PST 2006
  */
 #ifndef AUTOOPTS_PROTO_H_GUARD
 #define AUTOOPTS_PROTO_H_GUARD 1
@@ -11,9 +11,19 @@
 #else
 #  undef  REDEF_LOCAL
 #endif
-/*
- *  Extracted from autoopts.c
- */
+/*\n *  Extracted from autoopts.c\n */
+LOCAL void *
+ao_malloc( size_t sz );
+
+LOCAL void *
+ao_realloc( void *p, size_t sz );
+
+LOCAL void
+ao_free( void *p );
+
+LOCAL char *
+ao_strdup( char const *str );
+
 LOCAL tSuccess
 handleOption( tOptions* pOpts, tOptState* pOptState );
 
@@ -29,9 +39,7 @@ doImmediateOpts( tOptions* pOpts );
 LOCAL tSuccess
 doRegularOpts( tOptions* pOpts );
 
-/*
- *  Extracted from configfile.c
- */
+/*\n *  Extracted from configfile.c\n */
 LOCAL void
 internalFileLoad( tOptions* pOpts );
 
@@ -43,20 +51,16 @@ parseAttributes(
     tOptionValue*       pType );
 
 LOCAL tSuccess
-validateOptionsStruct( tOptions* pOpts, const char* pzProgram );
+validateOptionsStruct( tOptions* pOpts, char const* pzProgram );
 
-/*
- *  Extracted from environment.c
- */
+/*\n *  Extracted from environment.c\n */
 LOCAL void
 doPrognameEnv( tOptions* pOpts, teEnvPresetType type );
 
 LOCAL void
 doEnvPresets( tOptions* pOpts, teEnvPresetType type );
 
-/*
- *  Extracted from load.c
- */
+/*\n *  Extracted from load.c\n */
 LOCAL void
 mungeString( char* pzTxt, tOptionLoadMode mode );
 
@@ -68,15 +72,11 @@ loadOptionLine(
     tDirection  direction,
     tOptionLoadMode   load_mode );
 
-/*
- *  Extracted from sort.c
- */
+/*\n *  Extracted from sort.c\n */
 LOCAL void
 optionSort( tOptions* pOpts );
 
-/*
- *  Extracted from stack.c
- */
+/*\n *  Extracted from stack.c\n */
 LOCAL void
 addArgListEntry( void** ppAL, void* entry );
 
@@ -84,5 +84,4 @@ addArgListEntry( void** ppAL, void* entry );
 #  undef LOCAL
 #  define LOCAL
 #endif
-
 #endif /* AUTOOPTS_PROTO_H_GUARD */
