@@ -2,12 +2,12 @@
 
 /* --- fake the preprocessor into handlng portability */
 /*
- *  Time-stamp:      "2006-08-08 07:37:12 bkorb"
+ *  Time-stamp:      "2006-09-07 06:49:09 bkorb"
  *
  * Author:           Gary V Vaughan <gvaughan@oranda.demon.co.uk>
  * Created:          Mon Jun 30 15:54:46 1997
  *
- * $Id: compat.h,v 4.10 2006/08/08 14:49:04 bkorb Exp $
+ * $Id: compat.h,v 4.14 2006/11/27 01:52:23 bkorb Exp $
  */
 #ifndef COMPAT_H_GUARD
 #define COMPAT_H_GUARD 1
@@ -37,7 +37,9 @@
  *  SYSTEM HEADERS:
  */
 #include <sys/types.h>
-#include <sys/mman.h>
+#ifdef HAVE_SYS_MMAN_H
+#  include <sys/mman.h>
+#endif
 #include <sys/param.h>
 #if HAVE_SYS_PROCSET_H
 #  include <sys/procset.h>
@@ -198,9 +200,11 @@
 #endif /* !MAXPATHLEN && PATH_MAX */
 
 #if !defined (MAXPATHLEN)
-#  define MAXPATHLEN 4096
+#  define MAXPATHLEN ((size_t)4096)
 #endif /* MAXPATHLEN */
 
+#define AG_PATH_MAX  ((size_t)MAXPATHLEN)
+
 #ifndef LONG_MAX
 #  define LONG_MAX      ~(1L << (8*sizeof(long) -1))
 #  define INT_MAX       ~(1 << (8*sizeof(int) -1))
@@ -235,17 +239,17 @@
 
 #ifndef HAVE_INT32_T
 # if SIZEOF_INT == 4
-	typedef signed int      int32_t;
+        typedef signed int      int32_t;
 # elif SIZEOF_LONG == 4
-	typedef signed long     int32_t;
+        typedef signed long     int32_t;
 # endif
 #endif
 
 #ifndef HAVE_UINT32_T
 # if SIZEOF_INT == 4
-	typedef unsigned int    uint32_t;
+        typedef unsigned int    uint32_t;
 # elif SIZEOF_LONG == 4
-	typedef unsigned long   uint32_t;
+        typedef unsigned long   uint32_t;
 # else
 #   error Cannot create a uint32_t type.
     Choke Me.
@@ -305,7 +309,6 @@
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of compat/compat.h */
